@@ -1206,60 +1206,7 @@ char *terminal_util_hyperlink_uri_label (const char *uri)
     }
   }
 
-  return terminal_util_utf8_make_valid (unesc, -1);
-}
-
-/**
- * terminal_util_utf8_make_valid:
- *
- * Just as g_utf8_make_valid().
- *
- * FIXME: Use g_utf8_make_valid() instead once we require glib >= 2.52.
- */
-gchar *
-terminal_util_utf8_make_valid (const gchar *str,
-                               gssize       len)
-{
-  /* copied from glib's g_utf8_make_valid() implementation */
-  GString *string;
-  const gchar *remainder, *invalid;
-  gsize remaining_bytes, valid_bytes;
-
-  g_return_val_if_fail (str != NULL, NULL);
-
-  if (len < 0)
-    len = strlen (str);
-
-  string = NULL;
-  remainder = str;
-  remaining_bytes = len;
-
-  while (remaining_bytes != 0)
-    {
-      if (g_utf8_validate (remainder, remaining_bytes, &invalid))
-	break;
-      valid_bytes = invalid - remainder;
-
-      if (string == NULL)
-	string = g_string_sized_new (remaining_bytes);
-
-      g_string_append_len (string, remainder, valid_bytes);
-      /* append U+FFFD REPLACEMENT CHARACTER */
-      g_string_append (string, "\357\277\275");
-
-      remaining_bytes -= valid_bytes + 1;
-      remainder = invalid + 1;
-    }
-
-  if (string == NULL)
-    return g_strndup (str, len);
-
-  g_string_append_len (string, remainder, remaining_bytes);
-  g_string_append_c (string, '\0');
-
-  g_assert (g_utf8_validate (string->str, -1, NULL));
-
-  return g_string_free (string, FALSE);
+  return g_utf8_make_valid (unesc, -1);
 }
 
 #define TERMINAL_CACHE_DIR                 "gnome-terminal"
@@ -1609,3 +1556,25 @@ terminal_util_find_program_in_path (const char *path,
 }
 
 /* END code copied from glib */
+
+/*
+ * terminal_util_check_envv:
+ * @strv:
+ *
+ * Validates that each element is of the form 'KEY=VALUE'.
+ */
+gboolean
+terminal_util_check_envv(char const* const* strv)
+{
+  if (!strv)
+    return TRUE;
+
+  for (int i = 0; strv[i]; ++i) {
+          const char *str = strv[i];
+          const char *equal = strchr(str, '=');
+          if (equal == NULL || equal == str)
+                  return FALSE;
+  }
+
+  return TRUE;
+}
